pub struct MockClock { /* private fields */ }Expand description
A deterministic clock backed by manually-advanced inner state.
Clone shares the same inner state — the same handle can be installed in a subsystem
(Arc<dyn Clock>) and held by the test (Arc<MockClock>) to advance time.
Implementations
Sourceimpl MockClock
impl MockClock
Sourcepub fn advance(&self, dur: Duration)
pub fn advance(&self, dur: Duration)
Advance the clock by dur. All wakeups whose deadline is <= self.now() + dur resolve.
Sourcepub fn advance_secs(&self, secs: u64)
pub fn advance_secs(&self, secs: u64)
Advance the clock by secs seconds. Sugar for MockClock::advance.
Sourcepub fn advance_to_next_wakeup(&self) -> Option<Duration>
pub fn advance_to_next_wakeup(&self) -> Option<Duration>
Advance the clock to the deadline of the next pending wakeup, returning the elapsed
duration. Returns None when no wakeups are pending.
Sourcepub fn next_wakeup_in(&self) -> Option<Duration>
pub fn next_wakeup_in(&self) -> Option<Duration>
Peek at the duration until the next pending wakeup, without advancing the clock.
Returns None when no wakeups are pending.