referrerpolicy=no-referrer-when-downgrade

MockClock

Struct MockClock 

pub struct MockClock { /* private fields */ }
Test clock storing wall-clock milliseconds since the UNIX epoch.

Implementations

Source

impl MockClock

pub fn new_at_millis(millis: u64) -> Self

Create a new clock fixed at the given wall-clock time in milliseconds since the UNIX epoch.

pub fn new_at_secs(secs: u64) -> Self

Create a new clock fixed at the given wall-clock time in seconds since the UNIX epoch.

pub fn inc(&self, dur: Duration)

Advance the clock by dur.

pub fn inc_secs(&self, secs: u64)

Advance the clock by secs seconds.

pub fn set_millis(&self, millis: u64)

Set the clock to the given wall-clock time in milliseconds since the UNIX epoch.

pub fn set_secs(&self, secs: u64)

Set the clock to the given wall-clock time in seconds since the UNIX epoch.