pub struct MockClock { /* private fields */ }Expand description
Test clock storing wall-clock milliseconds since the UNIX epoch.
Implementations
Sourceimpl MockClock
impl MockClock
Sourcepub fn new_at_millis(millis: u64) -> Self
pub fn new_at_millis(millis: u64) -> Self
Create a new clock fixed at the given wall-clock time in milliseconds since the UNIX epoch.
Sourcepub fn new_at_secs(secs: u64) -> Self
pub fn new_at_secs(secs: u64) -> Self
Create a new clock fixed at the given wall-clock time in seconds since the UNIX epoch.
Sourcepub fn set_millis(&self, millis: u64)
pub fn set_millis(&self, millis: u64)
Set the clock to the given wall-clock time in milliseconds since the UNIX epoch.